@@ -1,6 +1,8 @@
 from typing import Dict
 
 from deepdriver import logger
+from deepdriver.sdk.data_types.run import Run
+
 
 class Config:
 
@@ -13,7 +15,8 @@ class Config:
         from deepdriver.sdk.data_types.run import get_run
         # 서버로 config() 전송
         logger.debug("config update..")
-        return interface.update_config(get_run().run_id, self.Items())
+        run: Run = get_run()
+        return interface.update_config(run.run_id, run.team_name, run.exp_name, self.Items())
 
 
     def __setitem__(self, idx):
