@@ -62,6 +62,12 @@ class Image(Media):
 
         return json.dumps(self.to_dict(key_name, is_list, index))
 
+    def meta_json(self, key_name: str, is_list=False, index=0) -> str:
+        return json.dumps( {
+            "log_type": self.log_type,
+            "path": self.get_path(key_name, is_list, index),
+        })
+
     def to_dict(self, key_name: str, is_list=False, index=0):
         return {
             "log_type": self.log_type,
