@@ -10,6 +10,7 @@ import deepdriver.version as version
 URL_LOGIN = "/api/client/auth"
 URL_CREATE = "/api/client/experiment/create"
 URL_CREATE_HPO = "/api/client/experiment/create/hpo"
+URL_GET_HPO = "/api/client/experiment/get/hpo"
 URL_FINISH = "/api/client/run/finish"
 
 
@@ -66,7 +67,7 @@ def init(http_host: str ,exp_name: str="", team_name: str="", run_name: str="",
     logger.debug("init() response : " + rsp["message"])
     return rsp
 
-def create_hpo(http_host:str, exp_name: str="", team_name: str="", hpo_config: Dict=None):
+def create_hpo(http_host:str, exp_name: str="", team_name: str="", hpo_config: Dict=None) -> Dict:
 
     data ={
         "teamName": team_name,
@@ -87,6 +88,16 @@ def create_hpo(http_host:str, exp_name: str="", team_name: str="", hpo_config: D
     return rsp
 
 
+def get_hpo(http_host:str, exp_name: str="", team_name: str="") -> Dict:
+    data = {
+        "teamName": team_name,
+        "expName": exp_name,
+    }
+    url = ParseResult(scheme="http", netloc=http_host, path=URL_GET_HPO, params='', query='', fragment='').geturl()
+    rsp = post(url, data)
+    logger.debug("get_hpo() response : " + rsp["message"])
+    return rsp
+
 
 def finish(http_host: str ,data: Dict) -> Dict:
     url = ParseResult(scheme="http",netloc=http_host, path=URL_FINISH, params='', query='', fragment='').geturl()
